from sqlalchemy import *
from migrate import *
import migrate.changeset
from dictionaries.versions import views_helper
import re


def getTmcTables(meta):
    tmc1 = Table('tmc1', meta, autoload=True)
    tmc2 = Table('tmc2', meta, autoload=True)
    return [tmc1, tmc2]


def getBarcodes(meta):
    barcodes1 = Table('barcodes1', meta, autoload=True)
    barcodes2 = Table('barcodes2', meta, autoload=True)
    return [barcodes1, barcodes2]


def getPrices(meta):
    prices1 = Table('prices1', meta, autoload=True)
    prices2 = Table('prices2', meta, autoload=True)
    return [prices1, prices2]


def upgrade(migrate_engine):
    # Upgrade operations go here. Don't create your own engine; use the engine
    # named 'migrate_engine' imported from migrate.
    meta = MetaData(bind=migrate_engine)
    for tbl in getBarcodes(meta):
        if 'barcodesidxcode' not in [ind.name for ind in tbl.indexes]:
            Index('barcodesidxcode', tbl.c.barcode, unique=True).create()

    for tbl in getPrices(meta):
        if 'pricesidxbarcodedoc' not in [ind.name for ind in tbl.indexes]:
            Index('pricesidxbarcodedoc', tbl.c.barcode, tbl.c.documentid, tbl.c.doctype, unique=True).create()

    for tbl in getTmcTables(meta):
        documentquantlimit = Column('documentquantlimit', Numeric(precision=13, scale=3), nullable=True)
        if not 'documentquantlimit' in tbl.columns:
            documentquantlimit.create(tbl)

    views_helper.update_dic_view(migrate_engine, 'tmc')
    views_helper.update_dic_view(migrate_engine, 'barcodes')
    views_helper.update_dic_view(migrate_engine, 'prices')


def downgrade(migrate_engine):
    # Operations to reverse the above upgrade go here.
    meta = MetaData(bind=migrate_engine)
    conn = migrate_engine.connect()
    tblname = views_helper.get_table_name(migrate_engine, 'tmc')

    for tbl in getTmcTables(meta):
        if 'documentquantlimit' in tbl.columns:
            tbl.c.documentquantlimit.drop()

    for tbl in getBarcodes(meta):
        if 'barcodesidxbarcode' in [ind.name for ind in tbl.indexes]:
            Index('barcodesidxbarcode', tbl.c.barcode, unique=True).drop()
        if 'barcodesidxcode' in [ind.name for ind in tbl.indexes]:
            Index('barcodesidxcode', tbl.c.barcode, unique=True).drop()

    for tbl in getPrices(meta):
        if 'pricesidxbarcodedoc' in [ind.name for ind in tbl.indexes]:
            Index('pricesidxbarcodedoc', tbl.c.barcode, tbl.c.documentid, tbl.c.doctype, unique=True).drop()

    views_helper.update_dic_view(migrate_engine, 'barcodes')
    views_helper.update_dic_view(migrate_engine, 'prices')
    views_helper.update_dic_view(migrate_engine, 'tmc', tblname)
