from sqlalchemy import *
from migrate import *
from dictionaries.versions import views_helper

def getShopTable(meta):
    shop = Table('shop',meta,
        Column('code', String(255), nullable=False, primary_key=True),
        Column('title', String(255), nullable=True),
        Column('extendedoptions', Text, nullable=True),
    )
    return shop

def getTmcTables(meta):
    tmc1 = Table('tmc1', meta, autoload=True)
    tmc2 = Table('tmc2', meta, autoload=True)
    return [tmc1, tmc2]

def getCardTables(meta):
    card1 = Table('card1', meta, autoload=True)
    card2 = Table('card2', meta, autoload=True)
    return [card1, card2]

def upgrade(migrate_engine):
    meta = MetaData(bind = migrate_engine)
    #tmc - age
    for tbl in getTmcTables(meta):
        age = Column('age', Integer, nullable=True)
        if not 'age' in tbl.columns:
            age.create(tbl)
    views_helper.update_dic_view(migrate_engine, 'tmc')
    #indexes in card
    for tbl in getCardTables(meta):
        if 'cardnumber' not in [ind.name for ind in tbl.indexes]:
            Index('cardnumber', tbl.c.number, unique=True).create()
    views_helper.update_dic_view(migrate_engine, 'card')
    #shop - table
    table = getShopTable(meta)
    basename = table.name
    for suffix in ['1','2']:
        table.name = basename+suffix
        if not table.exists():
            table.create()
    # update view
    views_helper.create_or_replace(migrate_engine, 'shop', 'shop1')    

def downgrade(migrate_engine):
    meta = MetaData(bind = migrate_engine)
    #tmc - age
    tmc = views_helper.get_table_name(migrate_engine,'tmc')
    for tbl in getTmcTables(meta):
        if 'age' in tbl.columns:
            tbl.c.age.drop()
    views_helper.update_dic_view(migrate_engine, 'tmc', tmc)
    # drop indexes in card if exist
    for tbl in getCardTables(meta):
        if 'cardnumber' in [ind.name for ind in tbl.indexes]:
            Index('cardnumber', tbl.c.number, unique=True).drop()
    # drop table if exists
    table = getShopTable(meta)
    basename = table.name
    for suffix in ['1','2']:
        table.name = basename+suffix
        if table.exists():
            table.drop()
    # drop view
    views_helper.drop_if_exist(migrate_engine, basename)
