from sqlalchemy import *
from migrate import *
import migrate.changeset

def getButton(meta):
    button = Table('button', meta,
        Column('buttonid', Integer, nullable=False, primary_key=True, autoincrement=True),
        Column('code', Integer, nullable=False),
        Column('name', String(200), nullable=False),
        Column('tag', String(100), nullable=True),
        Column('rateobject', Integer, nullable=False),
        Column('ratetype', Integer, nullable=False),
        Column('ratevalue',Numeric(precision=15,scale=2),nullable=True),
        Column('maxratevalue',Numeric(precision=15,scale=2),nullable=True),
        Column('minratevalue',Numeric(precision=15,scale=2),nullable=True),
        Column('inputvalue',Numeric(precision=15,scale=2),nullable=False),
        mysql_engine='InnoDB'
    )
    return button

def getDocumentTable(meta):
    return Table('document',meta,autoload=True)
   
def getGoodsitemTable(meta):
    return Table('goodsitem',meta, autoload=True)

def getStornogoodsitemTable(meta):
    return Table('stornogoodsitem',meta, autoload=True)

def getDiscitemTable(meta):
    return Table('discitem',meta, autoload=True)

def upgrade(migrate_engine):
    meta = MetaData(bind = migrate_engine)
    button = getButton(meta)
    button.create()

    col1 = Column('buttonid', Integer, nullable=True)
    col2 = Column('buttonid', Integer, nullable=True)
    col3 = Column('buttonid', Integer, nullable=True)
    col4 = Column('buttonid', Integer, nullable=True)

    col1.create(getDocumentTable(meta))
    col2.create(getGoodsitemTable(meta))
    col3.create(getStornogoodsitemTable(meta))
    col4.create(getDiscitemTable(meta))

    cons1 = migrate.changeset.constraint.ForeignKeyConstraint([getDocumentTable(meta).c.buttonid], [button.c.buttonid], name = 'documentbuttonidfk')
    cons2 = migrate.changeset.constraint.ForeignKeyConstraint([getGoodsitemTable(meta).c.buttonid], [button.c.buttonid], name = 'goodsitembuttonidfk')
    cons3 = migrate.changeset.constraint.ForeignKeyConstraint([getStornogoodsitemTable(meta).c.buttonid], [button.c.buttonid], name = 'stornogoodsitembuttonidfk')
    cons4 = migrate.changeset.constraint.ForeignKeyConstraint([getDiscitemTable(meta).c.buttonid], [button.c.buttonid], name = 'discitembuttonidfk')

    cons1.create()
    cons2.create()
    cons3.create()
    cons4.create()

def downgrade(migrate_engine):
    meta = MetaData(bind = migrate_engine)

    button = getButton(meta)
    cons1 = migrate.changeset.constraint.ForeignKeyConstraint([getDocumentTable(meta).c.buttonid], [button.c.buttonid], name = 'documentbuttonidfk')
    cons2 = migrate.changeset.constraint.ForeignKeyConstraint([getGoodsitemTable(meta).c.buttonid], [button.c.buttonid], name = 'goodsitembuttonidfk')
    cons3 = migrate.changeset.constraint.ForeignKeyConstraint([getStornogoodsitemTable(meta).c.buttonid], [button.c.buttonid], name = 'stornogoodsitembuttonidfk')
    cons4 = migrate.changeset.constraint.ForeignKeyConstraint([getDiscitemTable(meta).c.buttonid], [button.c.buttonid], name = 'discitembuttonidfk')

    cons1.drop()
    cons2.drop()
    cons3.drop()
    cons4.drop()
    
    getGoodsitemTable(meta).c.buttonid.drop()    
    getStornogoodsitemTable(meta).c.buttonid.drop()
    getDiscitemTable(meta).c.buttonid.drop()    
    getDocumentTable(meta).c.buttonid.drop()
    
    button.drop()


