# -*- coding: utf-8 -*-
from sqlalchemy import *
from migrate import *
from documents.versions import dump

correctionsourcedocnum_column_name = 'correctionsourcedocnum'
correctionsourcedocdate_column_name = 'correctionsourcedocdate'
correctionreason_column_name = 'correctionreason'
correctiontype_column_name = 'correctiontype'


def getTables(meta):
    return Table('document', meta, autoload=True)

def getDocType(meta):
    return Table('documenttype', meta, autoload=True)

def getMoneyType(meta):
    return Table('moneyitemtype', meta, autoload=True)

def insertIfNotExist(table, params):
    if not select([table.c.name]).where(and_(table.c.doctype == params['doctype'], table.c.name == params['name'])).execute().first():
        table.insert().values(params).execute()


def upgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    dump.store(migrate_engine)
    tbl = getTables(meta)

    if correctionreason_column_name not in tbl.columns:
        Column(correctionreason_column_name, Integer, nullable=True).create(tbl)

    if correctionsourcedocnum_column_name not in tbl.columns:
        Column(correctionsourcedocnum_column_name, String(100), nullable=True).create(tbl)

    if correctionsourcedocdate_column_name not in tbl.columns:
        Column(correctionsourcedocdate_column_name, DateTime, nullable=True).create(tbl)

    if correctiontype_column_name not in tbl.columns:
        Column(correctiontype_column_name, Integer, nullable=True).create(tbl)

    insertIfNotExist(getDocType(meta), dict(doctype=26, moneyfactor=0, name='Чек коррекции прихода'))
    insertIfNotExist(getMoneyType(meta), dict(doctype=26, reverseoperation=0, factor=0, name='Коррекция прихода'))

    insertIfNotExist(getDocType(meta), dict(doctype=27, moneyfactor=0, name='Чек коррекции расхода'))
    insertIfNotExist(getMoneyType(meta), dict(doctype=27, reverseoperation=0, factor=0, name='Коррекция расхода'))


def downgrade(migrate_engine):
    meta = MetaData(bind=migrate_engine)
    tbl = getTables(meta)

    if correctionreason_column_name in tbl.columns:
        Column(correctionreason_column_name, Integer, nullable=True).drop(tbl)

    if correctionsourcedocnum_column_name in tbl.columns:
        Column(correctionsourcedocnum_column_name, String(100), nullable=True).drop(tbl)

    if correctionsourcedocdate_column_name in tbl.columns:
        Column(correctionsourcedocdate_column_name, DateTime, nullable=True).drop(tbl)

    if correctiontype_column_name in tbl.columns:
        Column(correctiontype_column_name, Integer, nullable=True).drop(tbl)
